@@ -16,8 +16,7 @@ def test_auto_mapper_date_literal(spark_session: SparkSession) -> None:
         [
             (1, 'Qureshi', 'Imran'),
             (2, 'Vidal', 'Michael'),
-        ],
-        ['member_id', 'last_name', 'first_name']
+        ], ['member_id', 'last_name', 'first_name']
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -27,15 +26,13 @@ def test_auto_mapper_date_literal(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
-    ).columns(
-        birthDate=A.date("1970-01-01")
-    )
+        view="members", source_view="patients", keys=["member_id"]
+    ).columns(birthDate=A.date("1970-01-01"))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
@@ -44,7 +41,8 @@ def test_auto_mapper_date_literal(spark_session: SparkSession) -> None:
             to_date(lit("1970-01-01"), format='yyyy-MM-dd'),
             to_date(lit("1970-01-01"), format='yyyyMMdd'),
             to_date(lit("1970-01-01"), format='MM/dd/yy')
-        ).alias("birthDate"))
+        ).alias("birthDate")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -52,5 +50,7 @@ def test_auto_mapper_date_literal(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("birthDate").collect()[0][0] == date(1970, 1, 1)
-    assert result_df.where("member_id == 2").select("birthDate").collect()[0][0] == date(1970, 1, 1)
+    assert result_df.where("member_id == 1").select("birthDate").collect(
+    )[0][0] == date(1970, 1, 1)
+    assert result_df.where("member_id == 2").select("birthDate").collect(
+    )[0][0] == date(1970, 1, 1)
