@@ -6,7 +6,7 @@ from pyspark.sql.functions import array
 from pyspark.sql.functions import lit
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.data_types.list import AutoMapperList
 
 
 def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
@@ -26,7 +26,7 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
     # Act
     mapper = AutoMapper(
         view="members", source_view="patients", keys=["member_id"]
-    ).columns(dst2=A.list(["address1", "address2"]))
+    ).columns(dst2=AutoMapperList(["address1", "address2"]))
 
     assert isinstance(mapper, AutoMapper)
     sql_expressions: Dict[str, Column] = mapper.get_column_specs(
